@@ -3,7 +3,7 @@
 asciiporn is designed for interactive graphics viewing within an ssh terminal
 by converting graphics into colorized ascii-art. asciiporn has 256 color support
 & is partially written in c for efficent graphics rendering.
-asciiporn can easily render 24bit megapixel graphics on a 1ghz 500mb machine
+asciiporn can easily render 24 bit megapixel graphics on a 1ghz 500mb machine
 
 screenshots of both image viewing & plotting r included w/ this distribution.
 asciiporn is hard-coded with lucida-console font, but courier font will work
@@ -35,7 +35,7 @@ for quick example usage, remotely run python in an ssh terminal:
 
 AUTHOR:
   kai zhu
-  kaizhu@ugcs.caltech.edu
+  kaizhu256@gmail.com
 
 REQUIREMENTS:
 - posix os
@@ -66,11 +66,11 @@ PLOT USAGE:
 
 2d plots take 3 main arguments:
   ft - a list of functions to plot
-  tmin, tmax - t domain
+  tmin, tmax - range of t
 
   >>> import asciiporn, numpy
   >>> asciiporn.plot(
-  ...   ft = [                  ## list of single argument functions
+  ...   ft = [                  ## list of single argument functions f(t)
   ...     numpy.cos,
   ...     numpy.sin,
   ...     lambda t: numpy.sin(t + 0.25),
@@ -108,11 +108,11 @@ l?*~_-----_>cC}lTl{7Tx_--------------------------------------------_+*Tll'*+_---
 
 
 3d plots have 2 extra arguments:
-  zmin, zmax - z domain
+  zmin, zmax - range of z
 
   >>> import asciiporn, numpy
   >>> asciiporn.plot3d(
-  ...   ftz = lambda t, z: numpy.sin(t + t*z), ## 3d function
+  ...   ftz = lambda t, z: numpy.sin(t + t*z), ## 3d function f(t, z)
   ...   tmin = 0.0, tmax = 7.0,                ## range of t
   ...   zmin = 0.0, zmax = 0.25,               ## range of z
   ... )
@@ -336,7 +336,7 @@ if sys.version_info[1] < 6: raise Exception("asciiporn requires Python 2.6 or hi
 
 
 __author__ = "kai zhu"
-__author_email__ = "kaizhu@ugcs.caltech.edu"
+__author_email__ = "kaizhu256@gmail.com"
 __description__ = """
 view color images & scientific plots in ssh terminal
 (screenshots using putty ssh terminal included)
@@ -351,7 +351,7 @@ __platforms__ = None
 __provides__ = None
 __requires__ = ["PIL", "numpy"]
 __url__ = "http://pypi.python.org/pypi/asciiporn"
-__version__ = "2009.02.01"
+__version__ = "2009.03.26"
 ## end setup info
 
 
@@ -363,7 +363,7 @@ if "DEBUG" not in globals(): DEBUG = 0 ## True prints debug info
 import ast, collections, re ## pseudomethod parser
 class parser(ast.NodeTransformer):
   def parse(self, s, fpath, mode):
-    s = s.replace(".items()", ".iteritems()").replace(".keys()", ".iterkeys()").replace(".values()", ".itervalues()")
+    # s = s.replace(".items()", ".iteritems()").replace(".keys()", ".iterkeys()").replace(".values()", ".itervalues()")
     s = s.replace("__next__", "next") ## PEP3114  Renaming iterator.next() to iterator.__next__()
 
     s = s.replace("..", ".__pseudomethod__.").replace("__pseudomethod__..", "..").replace("..__pseudomethod__", "..") ## parse pseudomethod syntax
@@ -403,7 +403,7 @@ class _importer(object):
     sys.path_importer_cache = {} ## reset cache
 
   def find_module(self, mname, path = None):
-    if DEBUG and 1: print( "py3k_syntax find_module(mname = %s, path = %s)" % (mname, path) )
+    if 0 and DEBUG: print( "py3k_syntax find_module(mname = %s, path = %s)" % (mname, path) )
 
     if path and len(path) is 1:
       x = path[0] + "."
@@ -425,7 +425,7 @@ class _importer(object):
 
   def load_module(self, mname):
     s, fpath, desc, tp = self.found
-    if DEBUG and 1: print( "py3k_syntax load_module(mname = %s, fpath = %s, desc = %s)" % (mname, fpath, desc) )
+    if 0 and DEBUG: print( "py3k_syntax load_module(mname = %s, fpath = %s, desc = %s)" % (mname, fpath, desc) )
 
     if mname in sys.modules: m = sys.modules[mname]; new = None ## if exist: use existing module
     else: m = sys.modules[mname] = imp.new_module(mname); new = True ## else: new module
@@ -459,6 +459,5 @@ if 1: ## builtins
 
 
 
-# importer.find_module("_asciiporn", path = __path__); _asciiporn = importer.load_module("_asciiporn")
 if "_asciiporn" in globals(): reload(_asciiporn)
 import _asciiporn; from _asciiporn import *; from _asciiporn import _asarray
